==> tkrat-1.0.tar.gz: tkrat-1.0/imap-4.1/src/osdep/tops-20/shortsym.h <==
/*
 * Program:	Definitions for compilers with 6-letter symbol limits
 *
 * Author:	Mark Crispin
 *		6158 Lariat Loop NE
 *		Bainbridge Island, WA  98110-2098
 *		Internet: MRC@Panda.COM
 *
 * Date:	24 May 1995
 * Last Edited:	22 January 1997
 *
 * Copyright 1997 by Mark Crispin
 *
 *  Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided
 * that the above copyright notices appear in all copies and that both the
 * above copyright notices and this permission notice appear in supporting
 * documentation, and that the name of Mark Crispin not be used in advertising
 * or publicity pertaining to distribution of the software without specific,
 * written prior permission.  This software is made available "as is", and
 * MARK CRISPIN DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, WITH REGARD TO
 * THIS SOFTWARE, INCLUDING WITHOUT LIMITATION ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, AND IN NO EVENT SHALL
 * MARK CRISPIN BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, TORT (INCLUDING NEGLIGENCE) OR STRICT
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 *
 */

#define auth_link a_link
#define auth_log a_log
#define auth_login_client al_cli
#define auth_login_server al_ser
#define authenticate a_auth
#define body_encodings bencds
#define body_types btypes
#define default_proto d_prot
#define dummy_append d_appn
#define dummy_canonicalize d_cano
#define dummy_check d_chck
#define dummy_close d_clos
#define dummy_copy d_copy
#define dummy_create d_crea
#define dummy_create_path d_crep
#define dummy_delete d_del
#define dummy_expunge d_exp
#define dummy_file d_fil
#define dummy_list d_list
#define dummy_list_work d_lstw
#define dummy_listed d_lstd
#define dummy_lsub d_lsub
#define dummy_open d_open
#define dummy_parameters d_parm
#define dummy_ping d_ping
#define dummy_rename d_ren
#define dummy_scan d_scan
#define dummy_search d_srch
#define dummy_valid d_val
#define env_parameters e_parm
#define fatal fatal
#define fs_get f_get
#define fs_give f_give
#define fs_resize f_resize
#define imap_OK i_OK
#define imap_append i_appn
#define imap_auth i_auth
#define imap_challenge i_chln
#define imap_check i_chck
#define imap_close i_clos
#define imap_copy i_copy
#define imap_create i_crea
#define imap_delete i_del
#define imap_expunge i_expn
#define imap_expunged i_expd
#define imap_fake i_fake
#define imap_fast i_fast
#define imap_flag i_flag
#define imap_flags i_flgs
#define imap_gc i_gc
#define imap_gc_body ig_bdy
#define imap_host i_host
#define imap_list i_list
#define imap_list_work il_wrk
#define imap_lsub i_lsub
#define imap_manage i_man
#define imap_msgdata i_msgd
#define imap_msgno i_msgn
#define imap_open i_open
#define imap_parameters i_parm
#define imap_parse_address ip_addr
#define imap_parse_adrlist ip_adrl
#define imap_parse_body ip_body
#define imap_parse_body_parameter ipb_pa
#define imap_parse_body_structure ipb_st
#define imap_parse_data ip_dat
#define imap_parse_disposition ip_dsp
#define imap_parse_envelope ip_env
#define imap_parse_extension ip_ext
#define imap_parse_flags ip_flg
#define imap_parse_header ip_hdr
#define imap_parse_language ip_lng
#define imap_parse_prop ip_prop
#define imap_parse_reply ip_rep
#define imap_parse_string ip_str
#define imap_parse_stringlist ip_stl
#define imap_parse_unsolicited ip_uns
#define imap_parse_user_flag ipu_fl
#define imap_ping i_ping
#define imap_rename i_ren
#define imap_reply i_rep
#define imap_response i_rspn
#define imap_scan i_scan
#define imap_search i_srch
#define imap_send i_send
#define imap_send_astring is_ast
#define imap_send_literal is_lit
#define imap_send_sdate iss_da
#define imap_send_slist iss_sl
#define imap_send_spgm iss_pg
#define imap_send_sset iss_st
#define imap_sout i_sout
#define imap_soutr i_sotr
#define imap_status i_stat
#define imap_structure i_stru
#define imap_subscribe i_sub
#define imap_uid i_uid
#define imap_unsubscribe i_uns
#define imap_valid i_val
#define internal_date in_dat
#define mail_append_full m_appn
#define mail_body m_body
#define mail_cdate m_cdat
#define mail_check m_chck
#define mail_close_full m_clos
#define mail_compare_address mc_adr
#define mail_compare_cstring mc_cst
#define mail_compare_msg mc_msg
#define mail_compare_sstring mc_sst
#define mail_compare_ulong mc_uln
#define mail_copy_full m_copy
#define mail_create m_crea
#define mail_criteria m_crit
#define mail_criteria_date mc_dat
#define mail_criteria_string mc_str
#define mail_date m_date
#define mail_debug m_dbug
#define mail_delete m_del
#define mail_elt m_elt
#define mail_exists m_exst
#define mail_expunge m_expn
#define mail_expunged m_expd
#define mail_fetch_body fs_bdy
#define mail_fetch_fast mf_fst
#define mail_fetch_flags mf_flg
#define mail_fetch_header mf_hdr
#define mail_fetch_message mf_msg
#define mail_fetch_mime mf_mim
#define mail_fetch_structure mf_str
#define mail_fetch_text mf_txt
#define mail_fetch_text_return mf_txr
#define mail_fetch_string_return mf_tsr
#define mail_fetchfrom mf_frm
#define mail_fetchsubject mf_sub
#define mail_filter m_filt
#define mail_flag m_flag
#define mail_free_address mr_add
#define mail_free_body mr_bdy
#define mail_free_body_data mrb_da
#define mail_free_body_parameter mrb_pr
#define mail_free_body_part mrb_pt
#define mail_free_cache mr_cac
#define mail_free_elt mr_elt
#define mail_free_envelope mr_env
#define mail_free_handle mr_han
#define mail_free_searchheader mrs_hd
#define mail_free_searchor mrs_or
#define mail_free_searchpgm mrs_pg
#define mail_free_searchpgmlist mrs_pl
#define mail_free_searchset mrs_st
#define mail_free_sortpgm mr_spg
#define mail_free_stringlist mr_sl
#define mail_gc m_gc
#define mail_gc_msg m_gcm
#define mail_initbody m_ibdy
#define mail_link m_link
#define mail_list m_list
#define mail_lock m_lock
#define mail_longdate ml_lda
#define mail_lookup_auth m_laut
#define mail_lookup_auth_name m_latn
#define mail_lsub m_lsub
#define mail_makehandle m_mhdl
#define mail_match_lines m_mlns
#define mail_msgno m_msgn
#define mail_newaddr mn_add
#define mail_newbody mn_bdy
#define mail_newbody_parameter mnb_pr
#define mail_newbody_part mnb_pt
#define mail_newbody_message_part mnb_mp
#define mail_new_cache_elt mn_elt
#define mail_newenvelope mn_env
#define mail_newsearchheader mns_hd
#define mail_newsearchor mns_or
#define mail_newsearchpgm mns_pg
#define mail_newsearchpgmlist mns_pl
#define mail_newsearchset mns_st
#define mail_newsortpgm mn_spg
#define mail_newstringlist mn_sl
#define mail_nodebug m_ndbg
#define mail_open m_open
#define mail_parameters m_parm
#define mail_parse_date mp_dat
#define mail_parse_flags mp_flg
#define mail_partial_body mpt_bd
#define mail_partial_text mpt_tx
#define mail_ping m_ping
#define mail_read m_read
#define mail_recent m_rcent
#define mail_rename m_ren
#define mail_scan m_scan
#define mail_search_addr ms_addr
#define mail_search_full m_srch
#define mail_search_gets ms_gets
#define mail_search_keyword ms_key
#define mail_search_msg ms_msg
#define mail_search_string ms_str
#define mail_search_text ms_txt
#define mail_sequence m_seq
#define mail_skip_fwd msk_fw
#define mail_skip_re msk_re
#define mail_sort ml_srt
#define mail_sort_compare ms_cmp
#define mail_status m_stat
#define mail_stream m_strm
#define mail_string m_strg
#define mail_string_init mt_ini
#define mail_string_next mt_nxt
#define mail_string_setpos mt_sps
#define mail_subscribe m_sub
#define mail_uid m_uid
#define mail_uid_sequence mu_seq
#define mail_unlock m_unl
#define mail_unsubscribe m_uns
#define mail_valid m_val
#define mail_valid_net mv_net
#define mail_valid_net_parse mvn_pr
#define mailboxfile mbxfil
#define mm_cache mm_cac
#define mm_critical mm_crt
#define mm_diskerror mm_dse
#define mm_dlog mm_dlg
#define mm_exists mm_exs
#define mm_expunged mm_exp
#define mm_fatal mm_ftl
#define mm_flags mm_flg
#define mm_list mm_lst
#define mm_log mm_log
#define mm_login mm_lgi
#define mm_lsub mm_lsb
#define mm_mailbox mm_mbx
#define mm_nocritical mm_ncr
#define mm_notify mm_not
#define mm_searched mm_src
#define myhomedir myhome
#define mylocalhost myhost
#define myusername_full myuser
#define net_aopen nt_aop
#define net_close nt_cls
#define net_getbuffer nt_gtb
#define net_getdata nt_gtd
#define net_getline nt_gtl
#define net_host nt_hst
#define net_localhost nt_lhs
#define net_open nt_opn
#define net_port nt_prt
#define net_sout nt_sot
#define net_soutr nt_str
#define netmsg_read nm_rea
#define netmsg_slurp nm_slr
#define netmsg_slurp_text nm_slt
#define netmsg_string nm_str
#define netmsg_string_init nm_ini
#define netmsg_string_next nm_nxt
#define netmsg_string_setpos nm_sps
#define newsrc_check_uid nsc_ui
#define newsrc_create ns_crea
#define newsrc_error ns_err
#define newsrc_lsub ns_lsub
#define newsrc_newmessages ns_nms
#define newsrc_newstate ns_nst
#define newsrc_read ns_rea
#define newsrc_status ns_sta
#define newsrc_update ns_upd
#define newsrc_write ns_wri
#define newsrc_write_error ns_wer
#define nntp_append n_appn
#define nntp_canonicalize n_cano
#define nntp_check n_chck
#define nntp_close n_clos
#define nntp_copy n_copy
#define nntp_create n_crea
#define nntp_delete n_del
#define nntp_expunge n_expn
#define nntp_fake n_fake
#define nntp_fetchfast nf_fst
#define nntp_fetchflags nf_flg
#define nntp_fetchmessage nf_msg
#define nntp_flagmsg n_fmsg
#define nntp_gc n_gc
#define nntp_header n_head
#define nntp_isvalid n_isvl
#define nntp_list n_list
#define nntp_lsub n_lsub
#define nntp_mail n_mail
#define nntp_mclose n_mcls
#define nntp_mopen n_mopn
#define nntp_open_full n_open
#define nntp_parameters n_parm
#define nntp_parsestructure n_pars
#define nntp_ping n_ping
#define nntp_rename n_ren
#define nntp_reply n_repl
#define nntp_scan n_scan
#define nntp_send n_send
#define nntp_soutr n_sout
#define nntp_status n_stat
#define nntp_subscribe n_sub
#define nntp_text n_text
#define nntp_text_slurp nt_slp
#define nntp_unsubscribe n_uns
#define nntp_valid n_val
#define pop3_append p_appn
#define pop3_check p_chck
#define pop3_close p_clos
#define pop3_copy p_copy
#define pop3_create p_crea
#define pop3_delete p_del
#define pop3_expunge p_exp
#define pop3_fake p_fake
#define pop3_fetchfast pf_fst
#define pop3_fetchflags pf_flg
#define pop3_fetchmessage pf_msg
#define pop3_gc p_gc
#define pop3_list p_list
#define pop3_lsub p_lsub
#define pop3_open p_open
#define pop3_parameters p_parm
#define pop3_parsestructure p_pars
#define pop3_ping p_ping
#define pop3_rename p_ren
#define pop3_reply p_rep
#define pop3_scan p_scan
#define pop3_send p_send
#define pop3_send_num ps_num
#define pop3_status p_stat
#define pop3_subscribe p_sub
#define pop3_unsubscribe p_uns
#define pop3_valid p_val
#define rfc822_8bit r
#define rfc822_address r_addr
#define rfc822_address_line ra_lin
#define rfc822_base64 r_b64
#define rfc822_binary r_bin
#define rfc822_cat r_cat
#define rfc822_contents r_cont
#define rfc822_cpy r_cpy
#define rfc822_cpy_adr rc_adr
#define rfc822_date r_date
#define rfc822_default_subtype rd_sub
#define rfc822_encode_body_7bit reb_7b
#define rfc822_encode_body_8bit reb_8b
#define rfc822_header r_head
#define rfc822_header_line rh_lin
#define rfc822_output r_out
#define rfc822_output_body ro_bdy
#define rfc822_parse_address rp_adr
#define rfc822_parse_addrspec rp_ads
#define rfc822_parse_adrlist rp_adl
#define rfc822_parse_content rp_cnt
#define rfc822_parse_content_header rpc_hd
#define rfc822_parse_group rp_grp
#define rfc822_parse_mailbox rp_mbx
#define rfc822_parse_msg rp_msg
#define rfc822_parse_phrase rp_phr
#define rfc822_parse_routeaddr rp_rte
#define rfc822_parse_word rp_wrd
#define rfc822_qprint r_qpnt
#define rfc822_quote r_quot
#define rfc822_skip_comment rs_cmt
#define rfc822_skipws rs_ws
#define rfc822_timezone r_tz
#define rfc822_write_address rw_adr
#define rfc822_write_body_header rwbh_8
#define server_login s_log
#define sm_read sm_rd
#define sm_subscribe sm_sub
#define sm_unsubscribe sm_uns
#define smtp_close s_clos
#define smtp_debug s_dbug
#define smtp_ehlo s_ehlo
#define smtp_fake s_fake
#define smtp_mail s_mail
#define smtp_nodebug s_nodb
#define smtp_open_full s_open
#define smtp_rcpt s_rcpt
#define smtp_reply s_repl
#define smtp_send s_send
#define smtp_soutr s_str
#define strcrlfcpy sc_cpy
#define strcrlflen sc_len
#define tcp_aopen t_aopn
#define tcp_clienthost t_chst
#define tcp_close t_clos
#define tcp_getbuffer tg_buf
#define tcp_getdata tg_dat
#define tcp_getline tg_lin
#define tcp_host t_host
#define tcp_localhost t_lhst
#define tcp_open t_open
#define tcp_parameters t_parameters
#define tcp_port t_port
#define tcp_sout t_sout
#define tcp_soutr t_str
#define textcpy txcopy
#define textcpystring txcpst
#define textcpyoffstring txcpos

==> tkrat_1.1.980117.orig.tar.gz: tkrat-1.1/imap-4.1/src/osdep/tops-20/shortsym.h <==
/*
 * Program:	Definitions for compilers with 6-letter symbol limits
 *
 * Author:	Mark Crispin
 *		6158 Lariat Loop NE
 *		Bainbridge Island, WA  98110-2098
 *		Internet: MRC@Panda.COM
 *
 * Date:	24 May 1995
 * Last Edited:	17 December 1997
 *
 * Copyright 1997 by Mark Crispin
 *
 *  Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, provided
 * that the above copyright notices appear in all copies and that both the
 * above copyright notices and this permission notice appear in supporting
 * documentation, and that the name of Mark Crispin not be used in advertising
 * or publicity pertaining to distribution of the software without specific,
 * written prior permission.  This software is made available "as is", and
 * MARK CRISPIN DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, WITH REGARD TO
 * THIS SOFTWARE, INCLUDING WITHOUT LIMITATION ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, AND IN NO EVENT SHALL
 * MARK CRISPIN BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, TORT (INCLUDING NEGLIGENCE) OR STRICT
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 *
 */

#define auth_link a_link
#define auth_log a_log
#define auth_login_client al_cli
#define auth_login_server al_ser
#define authenticate a_auth
#define body_encodings bencds
#define body_types btypes
#define default_proto d_prot
#define dummy_append d_appn
#define dummy_canonicalize d_cano
#define dummy_check d_chck
#define dummy_close d_clos
#define dummy_copy d_copy
#define dummy_create d_crea
#define dummy_create_path d_crep
#define dummy_delete d_del
#define dummy_expunge d_exp
#define dummy_file d_fil
#define dummy_list d_list
#define dummy_list_work d_lstw
#define dummy_listed d_lstd
#define dummy_lsub d_lsub
#define dummy_open d_open
#define dummy_parameters d_parm
#define dummy_ping d_ping
#define dummy_rename d_ren
#define dummy_scan d_scan
#define dummy_search d_srch
#define dummy_valid d_val
#define env_parameters e_parm
#define fatal fatal
#define file_string fl_str
#define file_string_init fl_ini
#define file_string_next fl_nxt
#define file_string_setpos fl_sps
#define fs_get f_get
#define fs_give f_give
#define fs_resize f_resize
#define imap_OK i_OK
#define imap_append i_appn
#define imap_auth i_auth
#define imap_cache i_cach
#define imap_challenge i_chln
#define imap_check i_chck
#define imap_close i_clos
#define imap_copy i_copy
#define imap_create i_crea
#define imap_delete i_del
#define imap_expunge i_expn
#define imap_fake i_fake
#define imap_fast i_fast
#define imap_flag i_flag
#define imap_flags i_flgs
#define imap_gc i_gc
#define imap_gc_body ig_bdy
#define imap_host i_host
#define imap_list i_list
#define imap_list_work il_wrk
#define imap_lsub i_lsub
#define imap_manage i_man
#define imap_msgdata i_msgd
#define imap_msgno i_msgn
#define imap_open i_open
#define imap_parameters i_parm
#define imap_parse_address ip_addr
#define imap_parse_adrlist ip_adrl
#define imap_parse_body_parameter ipb_pa
#define imap_parse_body_structure ipb_st
#define imap_parse_disposition ip_dsp
#define imap_parse_envelope ip_env
#define imap_parse_extension ip_ext
#define imap_parse_flags ip_flg
#define imap_parse_header ip_hdr
#define imap_parse_language ip_lng
#define imap_parse_namespace ip_nam
#define imap_parse_reply ip_rep
#define imap_parse_response ip_rsp
#define imap_parse_string ip_str
#define imap_parse_stringlist ip_stl
#define imap_parse_unsolicited ip_uns
#define imap_parse_user_flag ipu_fl
#define imap_ping i_ping
#define imap_rename i_ren
#define imap_reply i_rep
#define imap_response i_rspn
#define imap_scan i_scan
#define imap_search i_srch
#define imap_send i_send
#define imap_send_astring is_ast
#define imap_send_literal is_lit
#define imap_send_sdate iss_da
#define imap_send_slist iss_sl
#define imap_send_spgm iss_pg
#define imap_send_sset iss_st
#define imap_sort i_sort
#define imap_sout i_sout
#define imap_soutr i_sotr
#define imap_status i_stat
#define imap_structure i_stru
#define imap_subscribe i_sub
#define imap_thread i_thrd
#define imap_uid i_uid
#define imap_unsubscribe i_uns
#define imap_valid i_val
#define internal_date in_dat
#define mail_append_full m_appn
#define mail_auth m_auth
#define mail_body m_body
#define mail_cdate m_cdat
#define mail_check m_chck
#define mail_close_full m_clos
#define mail_compare_address mc_adr
#define mail_compare_cstring mc_cst
#define mail_compare_msg mc_msg
#define mail_compare_sstring mc_sst
#define mail_compare_ulong mc_uln
#define mail_copy_full m_copy
#define mail_create m_crea
#define mail_criteria m_crit
#define mail_criteria_date mc_dat
#define mail_criteria_string mc_str
#define mail_date m_date
#define mail_debug m_dbug
#define mail_delete m_del
#define mail_elt m_elt
#define mail_exists m_exst
#define mail_expunge m_expn
#define mail_expunged m_expd
#define mail_fetch_body fs_bdy
#define mail_fetch_fast mf_fst
#define mail_fetch_flags mf_flg
#define mail_fetch_header mf_hdr
#define mail_fetch_message mf_msg
#define mail_fetch_mime mf_mim
#define mail_fetch_overview mf_ovr
#define mail_fetch_structure mf_str
#define mail_fetch_text mf_txt
#define mail_fetch_text_return mf_txr
#define mail_fetch_string_return mf_tsr
#define mail_fetchfrom mf_frm
#define mail_fetchsubject mf_sub
#define mail_filter m_filt
#define mail_flag m_flag
#define mail_free_address mr_add
#define mail_free_body mr_bdy
#define mail_free_body_data mrb_da
#define mail_free_body_parameter mrb_pr
#define mail_free_body_part mrb_pt
#define mail_free_cache mr_cac
#define mail_free_elt mr_elt
#define mail_free_envelope mr_env
#define mail_free_handle mr_han
#define mail_free_namespace mr_nsp
#define mail_free_searchheader mrs_hd
#define mail_free_searchor mrs_or
#define mail_free_searchpgm mrs_pg
#define mail_free_searchpgmlist mrs_pl
#define mail_free_searchset mrs_st
#define mail_free_sortpgm mr_spg
#define mail_free_stringlist mr_sls
#define mail_free_threadnode mr_thn
#define mail_gc m_gc
#define mail_gc_msg m_gcm
#define mail_gc_body m_gcb
#define mail_initbody m_ibdy
#define mail_link m_link
#define mail_list m_list
#define mail_lock m_lock
#define mail_longdate ml_lda
#define mail_lookup_auth m_laut
#define mail_lookup_auth_name m_latn
#define mail_lsub m_lsub
#define mail_makehandle m_mhdl
#define mail_match_lines m_mlns
#define mail_msgno m_msgn
#define mail_newaddr mn_add
#define mail_newbody mn_bdy
#define mail_newbody_parameter mnb_pr
#define mail_newbody_part mnb_pt
#define mail_newbody_message_part mnb_mp
#define mail_new_cache_elt mn_elt
#define mail_newenvelope mn_env
#define mail_newmsg mn_msg
#define mail_newsearchheader mns_hd
#define mail_newsearchor mns_or
#define mail_newsearchpgm mns_pg
#define mail_newsearchpgmlist mns_pl
#define mail_newsearchset mns_st
#define mail_newsortpgm mn_spg
#define mail_newstringlist mn_sls
#define mail_newthreadnode mn_thr
#define mail_nodebug m_ndbg
#define mail_open m_open
#define mail_parameters m_parm
#define mail_parse_date mp_dat
#define mail_parse_flags mp_flg
#define mail_partial_body mpt_bd
#define mail_partial_text mpt_tx
#define mail_ping m_ping
#define mail_read m_read
#define mail_recent m_rcent
#define mail_rename m_ren
#define mail_scan m_scan
#define mail_search_addr ms_adr
#define mail_search_body ms_bdy
#define mail_search_full m_srch
#define mail_search_gets ms_gts
#define mail_search_header ms_hdr
#define mail_search_keyword ms_key
#define mail_search_msg ms_msg
#define mail_search_string ms_str
#define mail_search_text ms_txt
#define mail_sequence m_seq
#define mail_skip_fwd msk_fw
#define mail_skip_re msk_re
#define mail_sort ml_srt
#define mail_sort_cache ms_csh
#define mail_sort_compare ms_cmp
#define mail_sort_loadcache ms_lcs
#define mail_sort_msgs ms_mgs
#define mail_status m_stat
#define mail_status_default m_stad
#define mail_stream m_strm
#define mail_string m_strg
#define mail_string_init mt_ini
#define mail_string_next mt_nxt
#define mail_string_setpos mt_sps
#define mail_subscribe m_sub
#define mail_thread m_thr
#define mail_threadlist mt_lst
#define mail_thread_msgs mt_mgs
#define mail_thread_compare_date mtc_da
#define mail_thread_orderedsubject mt_osb
#define mail_uid m_uid
#define mail_uid_sequence mu_seq
#define mail_unlock m_unl
#define mail_unsubscribe m_uns
#define mail_valid m_val
#define mail_valid_net mv_net
#define mail_valid_net_parse mvn_pr
#define mailboxfile mbxfil
#define mime2_decode m2_dec
#define mime2_text m2_txt
#define mime2_token m2_tok
#define mm_cache mm_cac
#define mm_critical mm_crt
#define mm_diskerror mm_dse
#define mm_dlog mm_dlg
#define mm_exists mm_exs
#define mm_expunged mm_exp
#define mm_fatal mm_ftl
#define mm_flags mm_flg
#define mm_list mm_lst
#define mm_log mm_log
#define mm_login mm_lgi
#define mm_lsub mm_lsb
#define mm_mailbox mm_mbx
#define mm_nocritical mm_ncr
#define mm_notify mm_not
#define mm_searched mm_src
#define myhomedir myhome
#define mylocalhost myhost
#define myusername_full myuser
#define net_aopen nt_aop
#define net_close nt_cls
#define net_getbuffer nt_gtb
#define net_getdata nt_gtd
#define net_getline nt_gtl
#define net_host nt_hst
#define net_localhost nt_lhs
#define net_open nt_opn
#define net_port nt_prt
#define net_sout nt_sot
#define net_soutr nt_str
#define netmsg_read nm_rea
#define netmsg_slurp nm_slr
#define netmsg_slurp_text nm_slt
#define newsrc_check_uid nsc_ui
#define newsrc_create ns_crea
#define newsrc_error ns_err
#define newsrc_lsub ns_lsub
#define newsrc_newmessages ns_nms
#define newsrc_newstate ns_nst
#define newsrc_read ns_rea
#define newsrc_status ns_sta
#define newsrc_update ns_upd
#define newsrc_write ns_wri
#define newsrc_write_error ns_wer
#define nntp_append n_appn
#define nntp_canonicalize n_cano
#define nntp_check n_chck
#define nntp_close n_clos
#define nntp_copy n_copy
#define nntp_create n_crea
#define nntp_delete n_del
#define nntp_expunge n_expn
#define nntp_fake n_fake
#define nntp_fetchfast nf_fst
#define nntp_fetchflags nf_flg
#define nntp_fetchmessage nf_msg
#define nntp_flagmsg n_fmsg
#define nntp_gc n_gc
#define nntp_header n_head
#define nntp_isvalid n_isvl
#define nntp_list n_list
#define nntp_lsub n_lsub
#define nntp_mail n_mail
#define nntp_mclose n_mcls
#define nntp_mopen n_mopn
#define nntp_open_full n_open
#define nntp_parameters n_parm
#define nntp_parsestructure n_pars
#define nntp_ping n_ping
#define nntp_rename n_ren
#define nntp_reply n_repl
#define nntp_scan n_scan
#define nntp_send n_send
#define nntp_send_work n_sndw
#define nntp_sort n_sort
#define nntp_sort_loadcache ns_lcs
#define nntp_soutr n_sout
#define nntp_status n_stat
#define nntp_subscribe n_sub
#define nntp_text n_text
#define nntp_text_slurp nt_slp
#define nntp_thread n_thrd
#define nntp_unsubscribe n_uns
#define nntp_valid n_val
#define pop3_append p_appn
#define pop3_check p_chck
#define pop3_close p_clos
#define pop3_copy p_copy
#define pop3_create p_crea
#define pop3_delete p_del
#define pop3_expunge p_exp
#define pop3_fake p_fake
#define pop3_fetchfast pf_fst
#define pop3_fetchflags pf_flg
#define pop3_fetchmessage pf_msg
#define pop3_gc p_gc
#define pop3_list p_list
#define pop3_lsub p_lsub
#define pop3_open p_open
#define pop3_parameters p_parm
#define pop3_parsestructure p_pars
#define pop3_ping p_ping
#define pop3_rename p_ren
#define pop3_reply p_rep
#define pop3_scan p_scan
#define pop3_send p_send
#define pop3_send_num ps_num
#define pop3_status p_stat
#define pop3_subscribe p_sub
#define pop3_unsubscribe p_uns
#define pop3_valid p_val
#define rfc822_8bit r
#define rfc822_address r_addr
#define rfc822_address_line ra_lin
#define rfc822_base64 r_b64
#define rfc822_binary r_bin
#define rfc822_cat r_cat
#define rfc822_contents r_cont
#define rfc822_cpy r_cpy
#define rfc822_cpy_adr rc_adr
#define rfc822_date r_date
#define rfc822_default_subtype rd_sub
#define rfc822_encode_body_7bit reb_7b
#define rfc822_encode_body_8bit reb_8b
#define rfc822_header r_head
#define rfc822_header_line rh_lin
#define rfc822_output r_out
#define rfc822_output_body ro_bdy
#define rfc822_parse_address rp_adr
#define rfc822_parse_addrspec rp_ads
#define rfc822_parse_adrlist rp_adl
#define rfc822_parse_content rp_cnt
#define rfc822_parse_content_header rpc_hd
#define rfc822_parse_group rp_grp
#define rfc822_parse_mailbox rp_mbx
#define rfc822_parse_msg rp_msg
#define rfc822_parse_phrase rp_phr
#define rfc822_parse_routeaddr rp_rte
#define rfc822_parse_word rp_wrd
#define rfc822_qprint r_qpnt
#define rfc822_quote r_quot
#define rfc822_skip_comment rs_cmt
#define rfc822_skipws rs_ws
#define rfc822_timezone r_tz
#define rfc822_write_address rw_adr
#define rfc822_write_body_header rwbh_8
#define server_login s_log
#define sm_read sm_rd
#define sm_subscribe sm_sub
#define sm_unsubscribe sm_uns
#define smtp_close s_clos
#define smtp_debug s_dbug
#define smtp_ehlo s_ehlo
#define smtp_fake s_fake
#define smtp_mail s_mail
#define smtp_nodebug s_nodb
#define smtp_open_full s_open
#define smtp_rcpt s_rcpt
#define smtp_reply s_repl
#define smtp_send s_send
#define smtp_soutr s_str
#define strcrlfcpy sc_cpy
#define strcrlflen sc_len
#define tcp_aopen t_aopn
#define tcp_clienthost t_chst
#define tcp_close t_clos
#define tcp_getbuffer tg_buf
#define tcp_getdata tg_dat
#define tcp_getline tg_lin
#define tcp_host t_host
#define tcp_localhost t_lhst
#define tcp_open t_open
#define tcp_parameters t_parameters
#define tcp_port t_port
#define tcp_sout t_sout
#define tcp_soutr t_str
#define textcpy txcopy
#define textcpystring txcpst
#define textcpyoffstring txcpos
#define utf8_iso2022text u8_i22
#define utf8_mime2text u8_mi2
#define utf8_searchpgm u8_spg
#define utf8_stringlist u8_lst
#define utf8_text u8_txt
